@@ -1,4 +1,6 @@
 """
+Source: https://developer-docs.amazon.com/sp-api/docs/marketplace-ids
+
 Country	marketplaceId	Country code
 Canada	A2EUQ1WTGCTBG2	CA
 United States of America	ATVPDKIKX0DER	US
@@ -50,29 +52,73 @@ class Marketplaces(Enum):
         marketplace_id = Marketplaces.UK.marketplace_id
     """
 
+    #: Amazon marketplace in United Arab Emirates (AE)
     AE = (f"{BASE_URL}-eu.amazon.com", "A2VIGQ35RCS4UG", "eu-west-1")
-    BE = (f"{BASE_URL}-eu.amazon.com", "AMEN7PMS3EDWL", "eu-west-1")
-    DE = (f"{BASE_URL}-eu.amazon.com", "A1PA6795UKMFR9", "eu-west-1")
-    PL = (f"{BASE_URL}-eu.amazon.com", "A1C3SOZRARQ6R3", "eu-west-1")
-    EG = (f"{BASE_URL}-eu.amazon.com", "ARBP9OOSHTCHU", "eu-west-1")
-    ES = (f"{BASE_URL}-eu.amazon.com", "A1RKKUPIHCS9HS", "eu-west-1")
-    FR = (f"{BASE_URL}-eu.amazon.com", "A13V1IB3VIYZZH", "eu-west-1")
-    GB = (f"{BASE_URL}-eu.amazon.com", "A1F83G8C2ARO7P", "eu-west-1")
-    IN = (f"{BASE_URL}-eu.amazon.com", "A21TJRUUN4KGV", "eu-west-1")
-    IT = (f"{BASE_URL}-eu.amazon.com", "APJ6JRA9NG5V4", "eu-west-1")
-    NL = (f"{BASE_URL}-eu.amazon.com", "A1805IZSGTT6HS", "eu-west-1")
-    SA = (f"{BASE_URL}-eu.amazon.com", "A17E79C6D8DWNP", "eu-west-1")
-    SE = (f"{BASE_URL}-eu.amazon.com", "A2NODRKZP88ZB9", "eu-west-1")
-    TR = (f"{BASE_URL}-eu.amazon.com", "A33AVAJ2PDY3EV", "eu-west-1")
-    UK = (f"{BASE_URL}-eu.amazon.com", "A1F83G8C2ARO7P", "eu-west-1")  # alias for GB
 
+    #: Amazon marketplace in Belgium (BE)
+    BE = (f"{BASE_URL}-eu.amazon.com", "AMEN7PMS3EDWL", "eu-west-1")
+
+    #: Amazon marketplace in Germany (DE)
+    DE = (f"{BASE_URL}-eu.amazon.com", "A1PA6795UKMFR9", "eu-west-1")
+
+    #: Amazon marketplace in Poland (PL)
+    PL = (f"{BASE_URL}-eu.amazon.com", "A1C3SOZRARQ6R3", "eu-west-1")
+
+    #: Amazon marketplace in Egypt (EG)
+    EG = (f"{BASE_URL}-eu.amazon.com", "ARBP9OOSHTCHU", "eu-west-1")
+
+    #: Amazon marketplace in Spain (ES)
+    ES = (f"{BASE_URL}-eu.amazon.com", "A1RKKUPIHCS9HS", "eu-west-1")
+
+    #: Amazon marketplace in France (FR)
+    FR = (f"{BASE_URL}-eu.amazon.com", "A13V1IB3VIYZZH", "eu-west-1")
+
+    #: Amazon marketplace in Great Britain (GB)
+    GB = (f"{BASE_URL}-eu.amazon.com", "A1F83G8C2ARO7P", "eu-west-1")
+
+    #: Amazon marketplace in India (IN)
+    IN = (f"{BASE_URL}-eu.amazon.com", "A21TJRUUN4KGV", "eu-west-1")
+
+    #: Amazon marketplace in Italy (IT)
+    IT = (f"{BASE_URL}-eu.amazon.com", "APJ6JRA9NG5V4", "eu-west-1")
+
+    #: Amazon marketplace in Netherlands (NL)
+    NL = (f"{BASE_URL}-eu.amazon.com", "A1805IZSGTT6HS", "eu-west-1")
+
+    #: Amazon marketplace in Saudi Arabia (SA)
+    SA = (f"{BASE_URL}-eu.amazon.com", "A17E79C6D8DWNP", "eu-west-1")
+
+    #: Amazon marketplace in Sweden (SE)
+    SE = (f"{BASE_URL}-eu.amazon.com", "A2NODRKZP88ZB9", "eu-west-1")
+
+    #: Amazon marketplace in Turkey (TR)
+    TR = (f"{BASE_URL}-eu.amazon.com", "A33AVAJ2PDY3EV", "eu-west-1")
+
+    #: Amazon marketplace in United Kingdom (UK) - alias for GB
+    UK = (f"{BASE_URL}-eu.amazon.com", "A1F83G8C2ARO7P", "eu-west-1")
+
+    #: Amazon marketplace in South Africa (ZA)
+    ZA = (f"{BASE_URL}-eu.amazon.com", "AE08WJ6YKNBMC", "eu-west-1")
+
+    #: Amazon marketplace in Australia (AU)
     AU = (f"{BASE_URL}-fe.amazon.com", "A39IBJ37TRP1C6", "us-west-2")
+
+    #: Amazon marketplace in Japan (JP)
     JP = (f"{BASE_URL}-fe.amazon.com", "A1VC38T7YXB528", "us-west-2")
+
+    #: Amazon marketplace in Singapore (SG)
     SG = (f"{BASE_URL}-fe.amazon.com", "A19VAU5U5O7RUS", "us-west-2")
 
+    #: Amazon marketplace in United States (US)
     US = (f"{BASE_URL}-na.amazon.com", "ATVPDKIKX0DER", "us-east-1")
+
+    #: Amazon marketplace in Brazil (BR)
     BR = (f"{BASE_URL}-na.amazon.com", "A2Q3Y263D00KWC", "us-east-1")
+
+    #: Amazon marketplace in Canada (CA)
     CA = (f"{BASE_URL}-na.amazon.com", "A2EUQ1WTGCTBG2", "us-east-1")
+
+    #: Amazon marketplace in Mexico (MX)
     MX = (f"{BASE_URL}-na.amazon.com", "A1AM78C64UM0Y8", "us-east-1")
 
     def __init__(self, endpoint, marketplace_id, region):
